package com.tongran.mtragent.mapper;

import com.tongran.mtragent.domain.RmMtrProbeResult;

import java.util.List;

/**
 * 网络mtr探测结果Mapper接口
 * 
 * @author tongran
 * @date 2025-11-20
 */
public interface RmMtrProbeResultMapper 
{
    /**
     * 查询网络mtr探测结果
     * 
     * @param id 网络mtr探测结果主键
     * @return 网络mtr探测结果
     */
    public RmMtrProbeResult selectRmMtrProbeResultById(Long id);

    /**
     * 查询网络mtr探测结果列表
     * 
     * @param rmMtrProbeResult 网络mtr探测结果
     * @return 网络mtr探测结果集合
     */
    public List<RmMtrProbeResult> selectRmMtrProbeResultList(RmMtrProbeResult rmMtrProbeResult);

    /**
     * 新增网络mtr探测结果
     * 
     * @param rmMtrProbeResult 网络mtr探测结果
     * @return 结果
     */
    public int insertRmMtrProbeResult(RmMtrProbeResult rmMtrProbeResult);

    /**
     * 修改网络mtr探测结果
     * 
     * @param rmMtrProbeResult 网络mtr探测结果
     * @return 结果
     */
    public int updateRmMtrProbeResult(RmMtrProbeResult rmMtrProbeResult);

    /**
     * 删除网络mtr探测结果
     * 
     * @param id 网络mtr探测结果主键
     * @return 结果
     */
    public int deleteRmMtrProbeResultById(Long id);

    /**
     * 批量删除网络mtr探测结果
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteRmMtrProbeResultByIds(Long[] ids);

    void batchInsertRmMtrProbeResult(RmMtrProbeResult batchData);

    /**
     * 分表查询
     * @param condition
     * @return
     */
    List<RmMtrProbeResult> selectByCondition(RmMtrProbeResult condition);
}
